import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["listType"],
    _excluded2 = ["title", "children", "btnType", "btnText", "disabled", "width", "filterItems", "getTableData", "columns", "rowSelection", "pagination", "rowKey", "confirmText", "itemWidth", "initialValues", "onSubmit", "onClose", "formatPreviewItemValue"];
import React, { useMemo, useState, useEffect, useRef } from 'react';
import styles from "./index.module.less";
import { Drawer, Tooltip, message } from 'antd';
import { CloseCircleFilled, LeftOutlined, RightOutlined } from '@ant-design/icons';
import { unionBy, xorBy } from 'lodash';
import YwFilter from "../YwFilter";
import YwTable from "../YwTable";
import YwButton from "../YwButton";
import { isObject } from "../../utils/index";
import YwCardList from "../YwCardList/index";
import { UpIcon, DownIcon } from "../common/icon";
var DataList = /*#__PURE__*/React.forwardRef(function (_ref, ref) {
  var listType = _ref.listType,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded);

  var extraProps = {
    getDataSource: rest.getTableData
  };
  return listType === 'card' ? /*#__PURE__*/React.createElement(YwCardList, _extends({
    ref: ref
  }, rest, extraProps, {
    className: styles['card-list'],
    listItemStyle: {
      height: '100%',
      paddingBottom: '20px'
    },
    style: {
      paddingBottom: 0
    },
    renderFooter: function renderFooter(props) {
      return null;
    }
  })) : /*#__PURE__*/React.createElement(YwTable, _extends({
    ref: ref
  }, rest, extraProps));
});

var PreviewList = function PreviewList(_ref2) {
  var dataSource = _ref2.dataSource,
      _ref2$pageSize = _ref2.pageSize,
      pageSize = _ref2$pageSize === void 0 ? 10 : _ref2$pageSize,
      deleteItem = _ref2.deleteItem,
      rowKey = _ref2.rowKey,
      maxItems = _ref2.maxItems,
      setStyleBottom = _ref2.setStyleBottom,
      formatPreviewItemValue = _ref2.formatPreviewItemValue,
      renderMaxItemsMessageError = _ref2.renderMaxItemsMessageError;
  var total = useMemo(function () {
    return dataSource.length || 0;
  }, [dataSource]); // 倒序显示

  var perviewData = useMemo(function () {
    return dataSource || [];
  }, [dataSource]);
  useEffect(function () {
    setIsShow(total > 0);
    return function () {
      setPageIndex(1);
      setIsShow(false);
    };
  }, [total]);

  var _useState = useState(1),
      pageIndex = _useState[0],
      setPageIndex = _useState[1];

  var _useState2 = useState(false),
      isShow = _useState2[0],
      setIsShow = _useState2[1];

  useEffect(function () {
    (dataSource === null || dataSource === void 0 ? void 0 : dataSource.length) === 0 && setIsShow(false);
  }, [dataSource]);
  useEffect(function () {
    setStyleBottom(isShow ? 120 : 35);
  }, [isShow]);
  var startIdx = useMemo(function () {
    return pageIndex === 1 ? 0 : pageSize * (pageIndex - 1);
  }, [pageIndex, total]);
  var endIdx = useMemo(function () {
    return pageIndex * pageSize >= total ? total : pageSize * pageIndex;
  }, [pageIndex, total]);
  return /*#__PURE__*/React.createElement("div", {
    className: styles['preview-container'] + " " + (!isShow ? styles['preview-container-close'] : '')
  }, /*#__PURE__*/React.createElement("div", {
    className: styles['preview-container-bar']
  }, /*#__PURE__*/React.createElement("div", {
    className: styles['preview-container-bar-left']
  }, /*#__PURE__*/React.createElement("span", {
    style: {
      marginRight: '12px'
    }
  }, "\u5DF2\u9009\u62E9 ", total, " \u4E2A"), (dataSource === null || dataSource === void 0 ? void 0 : dataSource.length) > maxItems && /*#__PURE__*/React.createElement("span", {
    style: {
      marginRight: '12px',
      color: '#F15A5A'
    }
  }, renderMaxItemsMessageError(maxItems)), isShow ? /*#__PURE__*/React.createElement(DownIcon, {
    onClick: function onClick() {
      setIsShow(false);
    }
  }) : /*#__PURE__*/React.createElement(UpIcon, {
    onClick: function onClick() {
      setIsShow(true);
    }
  })), /*#__PURE__*/React.createElement("div", {
    className: styles['preview-container-bar-right'] + " " + (pageIndex * pageSize >= total ? styles.disabled : '')
  }, /*#__PURE__*/React.createElement("span", {
    className: styles['prev'] + " " + (pageIndex === 1 ? styles.disabled : ''),
    onClick: function onClick() {
      if (pageIndex > 1) {
        setPageIndex(pageIndex - 1);
      }
    }
  }, /*#__PURE__*/React.createElement(LeftOutlined, null)), /*#__PURE__*/React.createElement("span", {
    onClick: function onClick() {
      if (pageIndex * pageSize < total) {
        setPageIndex(pageIndex + 1);
      }
    },
    className: styles['next'] + " " + (pageIndex * pageSize >= total || total === 0 ? styles.disabled : '')
  }, /*#__PURE__*/React.createElement(RightOutlined, null)))), !!perviewData.length && /*#__PURE__*/React.createElement("div", {
    className: styles['preview-list']
  }, perviewData.slice(startIdx, endIdx).map(function (item, index) {
    var data = formatPreviewItemValue(item);
    var content = /*#__PURE__*/React.createElement("div", {
      className: styles['preview-item'],
      key: item[rowKey],
      onClick: function onClick() {
        deleteItem(item[rowKey], item);
      }
    }, /*#__PURE__*/React.createElement("span", {
      className: styles['order']
    }, index + 1 + pageSize * (pageIndex - 1)), /*#__PURE__*/React.createElement("img", {
      src: data.imgUrl,
      alt: ""
    }), /*#__PURE__*/React.createElement(CloseCircleFilled, {
      className: styles['close']
    }));
    return data.tooltip ? /*#__PURE__*/React.createElement(Tooltip, _extends({
      placement: "topLeft"
    }, data.tooltip), content) : content;
  })));
};

var YwDrawerSelector = function YwDrawerSelector(_ref3) {
  var title = _ref3.title,
      children = _ref3.children,
      btnType = _ref3.btnType,
      btnText = _ref3.btnText,
      disabled = _ref3.disabled,
      width = _ref3.width,
      filterItems = _ref3.filterItems,
      getTableData = _ref3.getTableData,
      columns = _ref3.columns,
      rowSelection = _ref3.rowSelection,
      pagination = _ref3.pagination,
      rowKey = _ref3.rowKey,
      confirmText = _ref3.confirmText,
      itemWidth = _ref3.itemWidth,
      initialValues = _ref3.initialValues,
      onSubmit = _ref3.onSubmit,
      _onClose = _ref3.onClose,
      formatPreviewItemValue = _ref3.formatPreviewItemValue,
      others = _objectWithoutPropertiesLoose(_ref3, _excluded2);

  var _useState3 = useState(others.visible || false),
      visible = _useState3[0],
      setVisible = _useState3[1];

  var _useState4 = useState(false),
      confirmLoading = _useState4[0],
      setConfirmLoading = _useState4[1];

  var formRef = useRef(null);

  var _useState5 = useState([]),
      selectedData = _useState5[0],
      setSelectedData = _useState5[1];

  var _useState6 = useState([]),
      selectedRowKeys = _useState6[0],
      setSelectedRowKeys = _useState6[1];

  var _useState7 = useState(initialValues),
      filterProps = _useState7[0],
      setFilterProps = _useState7[1]; // 预览底部边距


  var _useState8 = useState(35),
      styleBottom = _useState8[0],
      setStyleBottom = _useState8[1]; //   const onClose = () => {
  //     // setVisible(false);
  //   };


  var isControl = useMemo(function () {
    return others.visible !== undefined;
  }, [others.visible]);

  var handleInit = function handleInit() {
    // setFilterProps(initialValues || {});
    setConfirmLoading(false);
    setSelectedData([]);
    setSelectedRowKeys([]);
    formRef.current && formRef.current.reset();
  };

  useEffect(function () {
    setVisible(others.visible); // others.visible && handleInit();
  }, [others.visible]);
  useEffect(function () {
    if (visible) {
      handleInit();
    } else {
      setFilterProps(initialValues || {});
    }
  }, [visible]);

  var _rowSelection = _extends({}, rowSelection, {
    selectedRowKeys: selectedRowKeys,
    hideSelectTotal: true,
    // onChange: (keys, data, info) => {
    //   setSelectedData(unionBy(selectedData, data, rowKey));
    //   setSelectedRowKeys(union(selectedRowKeys, keys));
    // },
    onSelectAll: function onSelectAll(selected, _, changeRows) {
      if (selected) {
        var data = unionBy(changeRows, selectedData, rowKey) || [];
        setSelectedData(data);
        setSelectedRowKeys(data.map(function (v) {
          return v[rowKey];
        }));
      } else {
        var _data = xorBy(selectedData, changeRows, rowKey);

        setSelectedData(_data);
        setSelectedRowKeys(_data.map(function (v) {
          return v[rowKey];
        }));
      }
    },
    onSelect: function onSelect(record, selected) {
      if (selected) {
        var data = unionBy([record], selectedData, rowKey);
        setSelectedData(data);
        setSelectedRowKeys(data.map(function (v) {
          return v[rowKey];
        }));
      } else {
        setSelectedData(selectedData.filter(function (v) {
          return v[rowKey] !== record[rowKey];
        }));
        setSelectedRowKeys(selectedRowKeys.filter(function (v) {
          return v !== record[rowKey];
        }));
      }
    }
  });

  var renderFooter = function renderFooter() {
    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(YwButton, {
      btnText: confirmText,
      btnType: "primary",
      loading: confirmLoading,
      onClick: function onClick() {
        if (selectedRowKeys.length > others.maxItems) {
          message.error(others.renderMaxItemsMessageError(others.maxItems));
          setConfirmLoading(false);
          return;
        }

        if (others.minItems && selectedRowKeys.length < others.minItems) {
          message.error(others.renderMinItemsMessageError(others.minItems));
          setConfirmLoading(false);
          return;
        }

        setConfirmLoading(true);
        onSubmit(selectedRowKeys, selectedData).then(function () {
          !isControl ? setVisible(false) : _onClose();
        })["finally"](function () {
          setConfirmLoading(false);
        });
      }
    }), /*#__PURE__*/React.createElement(YwButton, {
      btnText: "\u5173\u95ED",
      style: {
        marginLeft: '12px'
      },
      onClick: function onClick() {
        !isControl ? setVisible(false) : _onClose();
      }
    }));
  };

  return /*#__PURE__*/React.createElement(React.Fragment, null, !isControl && /*#__PURE__*/React.createElement("div", {
    onClick: function onClick() {
      setVisible(true);
    },
    style: {
      display: 'inline-block'
    }
  }, children || /*#__PURE__*/React.createElement(YwButton, {
    btnText: btnText,
    btnType: btnType,
    disabled: disabled
  })), /*#__PURE__*/React.createElement(Drawer, {
    visible: visible,
    width: width,
    className: styles['yw-drawer-selector'],
    title: title,
    bodyStyle: {
      padding: '20px'
    },
    maskClosable: false,
    onClose: function onClose() {
      !isControl ? setVisible(false) : _onClose();
    },
    contentWrapperStyle: {
      display: visible ? 'block' : 'none'
    },
    keyboard: false,
    destroyOnClose: true,
    footerStyle: {
      display: 'flex',
      justifyContent: 'flex-end',
      alignItems: 'center'
    },
    footer: renderFooter()
  }, /*#__PURE__*/React.createElement(React.Fragment, null, filterItems && /*#__PURE__*/React.createElement(YwFilter, {
    itemWidth: itemWidth,
    labelInset: true,
    items: filterItems,
    columnGap: 15,
    initialValues: initialValues,
    onSubmit: function onSubmit(data) {
      setFilterProps(_extends({}, data));
    },
    onCreate: function onCreate(_form) {
      formRef.current = _form;
    }
  }), /*#__PURE__*/React.createElement("div", {
    className: styles['yw-drawer-selector-table-container'],
    style: {
      paddingBottom: styleBottom
    }
  }, visible && /*#__PURE__*/React.createElement(DataList, _extends({}, others, {
    filterProps: filterProps,
    getTableData: getTableData,
    columns: columns,
    rowSelection: _rowSelection,
    pagination: isObject(pagination) ? _extends({
      size: 'small'
    }, pagination) : pagination,
    listType: others.listType,
    rowKey: rowKey
  }))), /*#__PURE__*/React.createElement(PreviewList, {
    dataSource: selectedData,
    pageSize: 10,
    rowKey: rowKey,
    maxItems: others.maxItems,
    renderMaxItemsMessageError: others.renderMaxItemsMessageError,
    setStyleBottom: setStyleBottom,
    formatPreviewItemValue: formatPreviewItemValue,
    deleteItem: function deleteItem(key, data) {
      setSelectedData(selectedData.filter(function (v) {
        return v[rowKey] !== data[rowKey];
      }));
      setSelectedRowKeys(selectedRowKeys.filter(function (v) {
        return v !== key;
      }));
    }
  }))));
};

YwDrawerSelector.defaultProps = {
  width: '833px',
  pagination: {},
  rowSelection: {},
  rowKey: 'id',
  confirmText: '确认',
  listType: 'table',
  minItems: 0,
  renderMaxItemsMessageError: function renderMaxItemsMessageError(maxItems) {
    return "\u6700\u591A\u53EF\u9009 " + maxItems + " \u4E2A";
  },
  renderMinItemsMessageError: function renderMinItemsMessageError(minItems) {
    return "\u81F3\u5C11\u9009 " + minItems + " \u4E2A";
  } // itemWidth: 300,

};
export default YwDrawerSelector;