import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["maxRows", "itemWidth", "columnGap", "maxColumns", "minColumns"],
    _excluded2 = ["maxRows", "maxColumns", "minColumns", "items", "itemWidth", "initialValues", "size", "cache", "hasSearchBtn", "columnGap", "onSubmit", "onReset", "onValueChange", "onCreate", "labelInset"];
import React, { useMemo, Fragment, useEffect } from 'react';
import { Form, FormGrid, FormButtonGroup, Submit, Reset } from '@formily/antd';
import { observer, Observer, FormProvider, useParentForm } from '@formily/react';
import { observable } from '@formily/reactive';
import { createForm, onFormValuesChange, onFormInit } from '@formily/core';
import { useLocalStorageState, useSessionStorageState, useKeyPress } from 'ahooks';
import { useCollapseGrid } from "./useCollapseGrid";
import styles from "./index.module.less";
import { YwJsonForm } from "../YwJsonForm";
import { isFunction } from "../../utils/index";
import { DownIcon, UpIcon } from "../common/icon";
var obs = observable({
  "default": {
    isLine: true
  }
}); // 计算宽度处于临界值时会闪屏，不计算会出现临界值宽度溢出的问题，暂未解决方案
// const getComputedWidth = (isLine) => {
//   return `calc(100% - ${isLine ? 152 : 92}px)`;
// };

var QueryForm = observer(function (_ref) {
  var maxRows = _ref.maxRows,
      itemWidth = _ref.itemWidth,
      columnGap = _ref.columnGap,
      maxColumns = _ref.maxColumns,
      minColumns = _ref.minColumns,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  var _useCollapseGrid = useCollapseGrid({
    maxRows: maxRows,
    itemWidth: itemWidth,
    maxColumns: maxColumns,
    minColumns: minColumns,
    columnGap: columnGap
  }),
      grid = _useCollapseGrid.grid,
      expanded = _useCollapseGrid.expanded,
      toggle = _useCollapseGrid.toggle,
      isLine = _useCollapseGrid.isLine,
      type = _useCollapseGrid.type;

  var form = useParentForm();
  obs[form.id || 'default'].isLine = isLine;

  var renderButtonGroup = function renderButtonGroup() {
    if (type === 'collapsible') {
      return /*#__PURE__*/React.createElement(Fragment, null, /*#__PURE__*/React.createElement(FormButtonGroup, null, /*#__PURE__*/React.createElement("a", {
        style: {
          color: '#666',
          fontSize: '12px',
          display: 'flex',
          alignItems: 'center'
        },
        href: "",
        onClick: function onClick(e) {
          e.preventDefault();
          toggle();
        }
      }, !expanded ? /*#__PURE__*/React.createElement(React.Fragment, null, "\u5C55\u5F00", /*#__PURE__*/React.createElement(DownIcon, {
        style: {
          marginLeft: '9px'
        }
      })) : /*#__PURE__*/React.createElement(React.Fragment, null, "\u6536\u8D77", /*#__PURE__*/React.createElement(UpIcon, {
        style: {
          marginLeft: '9px'
        }
      })))));
    }
  };

  return /*#__PURE__*/React.createElement(Form, _extends({}, props, {
    feedbackLayout: "terse"
  }), /*#__PURE__*/React.createElement(FormGrid, {
    grid: grid
  }, props.children, /*#__PURE__*/React.createElement(FormGrid.GridColumn, {
    gridSpan: 24,
    style: {
      display: 'flex',
      justifyContent: 'center'
    }
  }, renderButtonGroup())));
});

var useCache = function useCache(key, props) {
  if (props === void 0) {
    props = {
      type: 'sessionStorage'
    };
  }

  var useHook = props.type === 'sessionStorage' ? useSessionStorageState : useLocalStorageState;

  var _useHook = useHook(key, _extends({
    defaultValue: undefined
  }, props)),
      message = _useHook[0],
      setMessage = _useHook[1];

  return {
    message: message,
    setMessage: setMessage
  };
};

export default function YwFilter(props) {
  var maxRows = props.maxRows,
      maxColumns = props.maxColumns,
      minColumns = props.minColumns,
      items = props.items,
      itemWidth = props.itemWidth,
      initialValues = props.initialValues,
      size = props.size,
      cache = props.cache,
      hasSearchBtn = props.hasSearchBtn,
      columnGap = props.columnGap,
      _onSubmit = props.onSubmit,
      onReset = props.onReset,
      onValueChange = props.onValueChange,
      onCreate = props.onCreate,
      labelInset = props.labelInset,
      others = _objectWithoutPropertiesLoose(props, _excluded2);

  var _items = [{
    component: QueryForm,
    type: 'void',
    componentProps: {
      minColumns: minColumns,
      maxColumns: maxColumns,
      columnGap: columnGap,
      rowGap: 12,
      itemWidth: itemWidth,
      maxRows: maxRows
    },
    children: items.map(function (v) {
      return _extends({}, v, {
        props: _extends({}, labelInset ? {
          inset: true
        } : {}, v.props ? v.props : {})
      });
    })
  }];
  var form = useMemo(function () {
    return createForm({
      initialValues: initialValues,
      effects: function effects() {
        onFormInit(function (form) {
          onCreate(form);
          obs[form.id || 'default'] = {
            isLine: true
          };
        });
        onFormValuesChange(function (form) {
          onValueChange(form.getValuesIn(), form);
        });
      }
    });
  }, []);
  var message = cache.message,
      setMessage = cache.setMessage;
  useEffect(function () {
    message && form.setValues(_extends({}, initialValues, message));
  }, [message]);
  useKeyPress('enter', function () {
    others.useKeyPress && form.submit().then(function (values) {
      _onSubmit(values);

      isFunction(setMessage) && setMessage(undefined);
    });
  }, {
    events: ['keyup'],
    target: function target() {
      return document.getElementById("yw-filter-" + (form.id || 'default'));
    }
  });
  return /*#__PURE__*/React.createElement("div", _extends({
    className: styles['yw-filter']
  }, others, {
    id: "yw-filter-" + (form.id || 'default')
  }), /*#__PURE__*/React.createElement(FormProvider, {
    form: form
  }, /*#__PURE__*/React.createElement("div", {
    className: styles['form-container']
  }, /*#__PURE__*/React.createElement(YwJsonForm, {
    style: {
      flex: 1
    },
    buttons: [],
    size: size,
    layoutProps: {
      colon: false
    },
    items: _items,
    form: form
  }), hasSearchBtn && /*#__PURE__*/React.createElement(Observer, null, function () {
    return /*#__PURE__*/React.createElement("div", {
      className: styles["group-btn-" + (!obs[form.id || 'default'].isLine ? 'col' : 'line')]
    }, /*#__PURE__*/React.createElement(Submit, {
      onSubmit: function onSubmit(values) {
        _onSubmit(values);

        isFunction(setMessage) && setMessage(values);
      }
    }, "\u67E5\u8BE2"), /*#__PURE__*/React.createElement(Reset, {
      onClick: function onClick() {
        if (isFunction(onReset)) {
          form.reset().then(function () {
            onReset(form);
          });
          return false;
        } else {
          form.reset().then(function () {
            form.submit().then(function (values) {
              _onSubmit(values);

              isFunction(setMessage) && setMessage(undefined);
            });
          });
        }
      }
    }, "\u91CD\u7F6E"));
  }))));
}
YwFilter.useCache = useCache;
YwFilter.defaultProps = {
  maxRows: 2,
  minColumns: 1,
  itemWidth: 328,
  columnGap: 20,
  items: [],
  hasSearchBtn: true,
  initialValues: {},
  children: null,
  cache: {},
  labelInset: false,
  onSubmit: function onSubmit() {},
  useKeyPress: true,
  onCreate: function onCreate() {},
  onValueChange: function onValueChange() {}
};