import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
import _extends from "@babel/runtime/helpers/extends";
var _excluded = ["ranges"];
import React, { useEffect, useState, useCallback } from 'react';
import { DatePicker as YDatePicker, TimePicker as YTimePicker, Space } from '@formily/antd';
import locale from 'antd/es/date-picker/locale/zh_CN';
import { isArrayField, onFieldValueChange } from '@formily/core';
import { useFormEffects } from '@formily/react';
import moment from 'moment';
import { Checkbox } from 'antd';
import { useField, useFieldSchema, useParentForm } from '@formily/react';
import { RANGES } from "../../utils";
import YwButton from "../YwButton/index";
var RangePicker = YDatePicker.RangePicker;
var common = {
  locale: locale
};

var Permanent = function Permanent(props) {
  var field = useField();
  var form = useParentForm();
  var schema = useFieldSchema();

  var _useState = useState(props.isPermanent),
      isPermanent = _useState[0],
      setIsPermanent = _useState[1];

  useEffect(function () {
    isPermanent && field.setValue(false);
  }, [isPermanent]);
  useFormEffects(function () {
    onFieldValueChange(schema.name, function (field) {
      var _field$value;

      !!((_field$value = field.value) !== null && _field$value !== void 0 && _field$value.length) && setIsPermanent(false);
    });
  });
  return isPermanent !== undefined && /*#__PURE__*/React.createElement(Checkbox // {...props}
  , {
    checked: isPermanent,
    style: {
      right: '-75px',
      position: 'absolute'
    },
    onChange: function onChange(e) {
      var checked = e.target.checked; // props.onChange && props.onChange(e.target.checked);

      setIsPermanent(checked);
      form.setValuesIn('isPermanent', checked);
      checked ? field.setRequired(false) : field.setRequired(schema.required);
    }
  }, "\u957F\u671F");
};

export var DateRangeGroup = function DateRangeGroup(_ref) {
  var ranges = _ref.ranges,
      _ref$rangesValue = _ref.rangesValue,
      rangesValue = _ref$rangesValue === void 0 ? {} : _ref$rangesValue,
      onChange = _ref.onChange;
  var field = useField();
  var schema = useFieldSchema();
  useFormEffects(function () {
    onFieldValueChange(schema.name, function (field) {
      onChange(field.value);
    });
  });
  return /*#__PURE__*/React.createElement(Space, null, ranges.map(function (v) {
    return /*#__PURE__*/React.createElement(YwButton, {
      type: "default",
      btnText: v,
      onClick: function onClick() {
        var timeArr = rangesValue[v] || RANGES[v];
        field.setValue(timeArr ? [timeArr[0].format('YYYY-MM-DD'), timeArr[1].format('YYYY-MM-DD')] : null);
      }
    });
  }));
};

var useMaxDates = function useMaxDates(_ref2) {
  var maxDates = _ref2.maxDates;

  var _useState2 = useState(null),
      dates = _useState2[0],
      setDates = _useState2[1];

  var _useState3 = useState(null),
      hackValue = _useState3[0],
      setHackValue = _useState3[1];

  var disabledDate = function disabledDate(current) {
    if (!dates) {
      return false;
    }

    var tooLate = dates[0] && current.diff(dates[0], 'days') > maxDates;
    var tooEarly = dates[1] && dates[1].diff(current, 'days') > maxDates;
    return !!tooEarly || !!tooLate;
  };

  var onOpenChange = function onOpenChange(open) {
    if (open) {
      setHackValue([null, null]);
      setDates([null, null]);
    } else {
      setHackValue(null);
    }
  };

  var onCalendarChange = function onCalendarChange(data) {
    setDates(data);
  };

  return maxDates !== undefined ? {
    disabledDate: disabledDate,
    onCalendarChange: onCalendarChange,
    onOpenChange: onOpenChange
  } : {};
};

var useFieldValue = function useFieldValue(field) {
  var getValue = useCallback(function () {
    return isArrayField(field) ? field.value[0] || '' : field.value || '';
  }, [field]);

  var _useState4 = useState(getValue()),
      value = _useState4[0],
      setValue = _useState4[1];

  useFormEffects(function () {
    onFieldValueChange(field.props.name, function () {
      setValue(getValue());
    });
  });
  return {
    value: value
  };
};

var formatProps = function formatProps(props) {
  return _extends({}, common, {
    allowClear: true
  }, props);
};

var formatRangeProps = function formatRangeProps(props) {
  return _extends({}, common, {
    allowClear: true
  }, props);
}; // 日期选择


export var DatePicker = function DatePicker(props) {
  var _props = formatProps(_extends({}, props, {
    picker: 'date'
  }));

  var field = useField();

  var _useFieldValue = useFieldValue(field),
      value = _useFieldValue.value;

  return /*#__PURE__*/React.createElement(YDatePicker, _extends({
    format: "YYYY-MM-DD"
  }, _props, {
    disabled: field.disabled,
    value: value,
    onChange: function onChange(date) {
      isArrayField(field) ? field.setValue([date ? date + " 00:00:00" : date, date ? date + " 23:59:59" : date]) : field.setValue(date);
    }
  }));
}; // 日期时间选择

export var DateTimePicker = function DateTimePicker(props) {
  var _props = formatProps(_extends({}, props, {
    picker: 'date',
    showTime: {
      hideDisabledOptions: true,
      defaultValue: props.defaultTime ? moment(props.defaultTime, 'HH:mm:ss') : moment('00:00:00', 'HH:mm:ss')
    }
  }));

  var field = useField();

  var _useFieldValue2 = useFieldValue(field),
      value = _useFieldValue2.value;

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(YDatePicker, _extends({
    format: "YYYY-MM-DD HH:mm:ss"
  }, _props, {
    disabled: field.disabled,
    value: value,
    onChange: function onChange(date) {
      isArrayField(field) ? field.setValue([date, date]) : field.setValue(date);
    }
  })));
}; // 月选择

export var MonthPicker = function MonthPicker(props) {
  var _props = formatProps(_extends({}, props, {
    picker: 'month'
  }));

  var field = useField();

  var _useFieldValue3 = useFieldValue(field),
      value = _useFieldValue3.value;

  return /*#__PURE__*/React.createElement(YDatePicker, _extends({}, _props, {
    value: value,
    disabled: field.disabled,
    onChange: function onChange(date) {
      isArrayField(field) ? field.setValue([date ? moment(date, 'YYYY-MM').startOf('month').format('YYYY-MM-DD') : date, date ? moment(date, 'YYYY-MM').endOf('month').format('YYYY-MM-DD') : date]) : field.setValue(date);
    }
  }));
};
export var WeekPicker = function WeekPicker(props) {
  var _props = formatProps(_extends({}, props, {
    picker: 'week'
  }));

  var field = useField();

  var _useFieldValue4 = useFieldValue(field),
      value = _useFieldValue4.value;

  return /*#__PURE__*/React.createElement(YDatePicker, _extends({}, _props, {
    value: value,
    disabled: field.disabled,
    onChange: function onChange(date) {
      field.setValue([date ? moment(date, 'YYYY-ww').startOf('week').format('YYYY-MM-DD') : date, date ? moment(date, 'YYYY-ww').endOf('week').format('YYYY-MM-DD') : date]);
    }
  }));
}; // 时间选择

export var TimePicker = function TimePicker(props) {
  var _props = formatProps(_extends({}, props));

  var field = useField();
  return /*#__PURE__*/React.createElement(YTimePicker, _extends({
    format: "HH:mm:ss"
  }, _props, {
    disabled: field.disabled
  }));
}; // range

export var WeekRangePicker = function WeekRangePicker(props) {
  var _props = formatRangeProps(_extends({}, props, {
    picker: 'week'
  }));

  var field = useField();

  var formatWeek = function formatWeek(date) {
    var _date;

    if (date === void 0) {
      date = [];
    }

    if (!((_date = date) !== null && _date !== void 0 && _date.length)) return [];
    return [moment(props.value[0], 'YYYY-MM-DD').format('YYYY-wo'), moment(props.value[1], 'YYYY-MM-DD').format('YYYY-wo')];
  };

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(RangePicker, _extends({
    separator: "-"
  }, _props, {
    value: formatWeek(props.value),
    disabled: field.disabled,
    onChange: function onChange(date) {
      field.setValue([date ? moment(date[0], 'YYYY-ww').startOf('week').format('YYYY-MM-DD') : date, date ? moment(date[1], 'YYYY-ww').endOf('week').format('YYYY-MM-DD') : date]);
    }
  })), props.isPermanent !== undefined && /*#__PURE__*/React.createElement(Permanent, {
    isPermanent: props.isPermanent
  }));
};
export var DateRangePicker = function DateRangePicker(_ref3) {
  var ranges = _ref3.ranges,
      props = _objectWithoutPropertiesLoose(_ref3, _excluded);

  var field = useField();

  var _ranges = Array.isArray(ranges) ? ranges.reduce(function (curr, prev) {
    if (!RANGES[prev]) {
      return curr;
    }

    curr[prev] = RANGES[prev];
    return curr;
  }, {}) : ranges || {};

  var _useMaxDates = useMaxDates({
    maxDates: props.maxDates
  }),
      disabledDate = _useMaxDates.disabledDate,
      onCalendarChange = _useMaxDates.onCalendarChange;

  var _props = formatRangeProps(_extends({
    disabledDate: disabledDate,
    onCalendarChange: onCalendarChange
  }, props, {
    ranges: _ranges,
    picker: 'date'
  }));

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(RangePicker, _extends({
    separator: "-"
  }, _props, {
    disabled: field.disabled
  })), props.isPermanent !== undefined && /*#__PURE__*/React.createElement(Permanent, {
    isPermanent: props.isPermanent
  }));
};
export var MonthRangePicker = function MonthRangePicker(props) {
  var _props = formatRangeProps(_extends({}, props, {
    picker: 'month'
  }));

  var field = useField();

  var formatMonth = function formatMonth(date) {
    var _date2;

    if (date === void 0) {
      date = [];
    }

    if (!((_date2 = date) !== null && _date2 !== void 0 && _date2.length)) return [];
    return [moment(props.value[0]).startOf('month').format('YYYY-MM'), moment(props.value[1]).startOf('month').format('YYYY-MM')];
  };

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(RangePicker, _extends({
    separator: "-"
  }, _props, {
    value: formatMonth(props.value),
    disabled: field.disabled,
    onChange: function onChange(date) {
      field.setValue([date ? moment(date[0]).startOf('month').format('YYYY-MM-DD') : date, date ? moment(date[1]).endOf('month').format('YYYY-MM-DD') : date]);
    }
  })), props.isPermanent !== undefined && /*#__PURE__*/React.createElement(Permanent, {
    isPermanent: props.isPermanent
  }));
};
export var DateTimeRangePicker = function DateTimeRangePicker(props) {
  var _props$defaultTime;

  var field = useField();

  var _useMaxDates2 = useMaxDates({
    maxDates: props.maxDates
  }),
      disabledDate = _useMaxDates2.disabledDate,
      onCalendarChange = _useMaxDates2.onCalendarChange;

  var _props = formatRangeProps(_extends({
    disabledDate: disabledDate,
    onCalendarChange: onCalendarChange
  }, props, {
    picker: 'date',
    showTime: {
      hideDisabledOptions: true,
      defaultValue: ((_props$defaultTime = props.defaultTime) === null || _props$defaultTime === void 0 ? void 0 : _props$defaultTime.length) > 0 ? [moment(props.defaultTime[0], 'HH:mm:ss'), moment(props.defaultTime[1], 'HH:mm:ss')] : [moment('00:00:00', 'HH:mm:ss'), moment('23:59:59', 'HH:mm:ss')]
    }
  }));

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(RangePicker, _extends({
    format: "YYYY-MM-DD HH:mm:ss",
    separator: "-"
  }, _props, {
    disabled: field.disabled
  })), props.isPermanent !== undefined && /*#__PURE__*/React.createElement(Permanent, {
    isPermanent: props.isPermanent
  }));
}; // 时间范围选择

export var TimeRangePicker = function TimeRangePicker(props) {
  var _props = formatRangeProps(_extends({}, props));

  var field = useField();
  return /*#__PURE__*/React.createElement(YTimePicker.RangePicker, _extends({
    format: "HH:mm:ss"
  }, _props, {
    disabled: field.disabled
  }));
};