'use strict';

var __assign = this && this.__assign || function () {
  __assign = Object.assign || function (t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];

      for (var p in s) {
        if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
      }
    }

    return t;
  };

  return __assign.apply(this, arguments);
};

var __rest = this && this.__rest || function (s, e) {
  var t = {};

  for (var p in s) {
    if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];
  }

  if (s != null && typeof Object.getOwnPropertySymbols === 'function') for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
};

var __spreadArrays = this && this.__spreadArrays || function () {
  for (var s = 0, i = 0, il = arguments.length; i < il; i++) {
    s += arguments[i].length;
  }

  for (var r = Array(s), k = 0, i = 0; i < il; i++) {
    for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++) {
      r[k] = a[j];
    }
  }

  return r;
};

exports.__esModule = true;

var react_1 = require('react');

var core_1 = require('@formily/core');

var antd_1 = require('@formily/antd');

var react_2 = require('@formily/react');

var YwTitle_1 = require("./YwTitle");

var hook_1 = require("./hook");

var YDatePicker_1 = require("./YDatePicker");

var YArrayTable_1 = require("./YArrayTable");

var rules_1 = require("./rules");

var TextArea = antd_1.Input.TextArea;
var RadioGroup = antd_1.Radio.Group;
var CheckboxGroup = antd_1.Checkbox.Group;
var customComponent = [];
var dataSource = {};
core_1.registerValidateFormats(rules_1.FORMATS);
core_1.registerValidateRules(rules_1.RULES);

var formatSchema = function formatSchema(item) {
  if (item === void 0) {
    item = {};
  }

  if (item.customComponent) {
    customComponent = __spreadArrays(customComponent, [item.customComponent]);
  }

  if (item.getDataSource) {
    dataSource[item.name] = item.getDataSource;
  }

  return __assign(__assign({
    type: item.type || 'void',
    title: item.title,
    description: item.description,
    "default": item.defaultValue,
    readOnly: item.readOnly,
    "enum": item['enum'],
    required: item.required,
    'x-validator': item.rules,
    'x-decorator': item.decorator || 'FormItem',
    'x-decorator-props': __assign(__assign({}, item.props), {
      getDataSource: item.getDataSource
    })
  }, item.getDataSource ? {
    'x-reactions': ['{{useAsyncDataSource(dataSource)}}']
  } : {}), {
    'x-component': item.component || item.customComponent,
    'x-component-props': item.componentProps,
    'x-visible': item.visible,
    'x-disabled': item.disabled,
    'x-read-pretty': item.preview
  });
};

function YwJsonForm(props) {
  var title = props.title,
      buttons = props.buttons,
      onCreate = props.onCreate,
      onSubmit = props.onSubmit,
      onValueChange = props.onValueChange,
      editable = props.editable,
      disabled = props.disabled,
      size = props.size,
      layoutProps = props.layoutProps,
      buttonsProps = props.buttonsProps,
      items = props.items,
      others = __rest(props, ['title', 'buttons', 'onCreate', 'onSubmit', 'onValueChange', 'editable', 'disabled', 'size', 'layoutProps', 'buttonsProps', 'items']);

  var form = props.form || react_1.useMemo(function () {
    return core_1.createForm({
      disabled: disabled,
      editable: editable,
      effects: function effects(form) {
        core_1.onFormInit(function () {
          onCreate(form);
        });
        core_1.onFormValuesChange(function (form) {
          onValueChange(form.getValuesIn(), form);
        });
        core_1.onFieldValueChange('target', function (field) {
          console.log('target值变化：' + field.value);
        });
      }
    });
  }, []);

  var FormGroup = function FormGroup(props) {
    return react_1['default'].createElement(react_1.Fragment, null, react_1['default'].createElement(YwTitle_1['default'], {
      size: props.size,
      text: props.text
    }), react_1['default'].createElement(antd_1.FormLayout, __assign({}, layoutProps, {
      size: size,
      style: {
        marginTop: '20px'
      }
    }), props.children));
  };

  var getItemsSchema = function getItemsSchema() {
    var formatItem = function formatItem(nodeList) {
      if (nodeList.length === 0) {
        return null;
      }

      var res = {};
      nodeList.forEach(function (item, idx) {
        if (item.component === 'FormGroup') {
          //分组标题
          res['NO_FIELD_NAME_' + idx] = __assign({
            type: 'void',
            'x-component': FormGroup,
            'x-decorator': 'FormItem',
            'x-visible': item.visible,
            'x-component-props': {
              size: size === 'small' ? 's' : 'm',
              text: item.title
            }
          }, item.children ? formatItem(item.children) : {});
        } else if (item.component === 'FormGrid') {
          //grid
          res['NO_FIELD_NAME_' + idx] = __assign(__assign({}, formatSchema(item)), item.children ? formatItem(item.children) : {} // properties: {
          //   layout: {
          //     type: 'void',
          //     'x-component': 'FormLayout',
          //     'x-component-props': {
          //       labelCol: 6,
          //       wrapperCol: 10,
          //     },
          //     ...(item.children ? formatItem(item.children) : {})
          //   }
          // }
          );
        } else if (item.component === 'ArrayTable') {
          //ArrayTable
          res[item.name] = __assign(__assign({}, formatSchema(item)), {
            type: 'array',
            'x-component-props': __assign(__assign({}, item.componentProps), {
              layoutProps: layoutProps,
              arrayConfig: item.children
            })
          });
        } else {
          res[item.name] = __assign(__assign({}, formatSchema(item)), item.children ? formatItem(item.children) : {});
        }
      });
      return {
        properties: res
      };
    };

    return formatItem(items || []);
  };

  var renderButtons = function renderButtons() {
    return buttons.length ? react_1['default'].createElement(antd_1.FormButtonGroup.FormItem, null, buttons === null || buttons === void 0 ? void 0 : buttons.map(function (btn) {
      var _component = {
        submit: react_1['default'].createElement(antd_1.Submit, {
          key: 'submit',
          onSubmit: onSubmit,
          size: size
        }, "\u63D0\u4EA4"),
        reset: react_1['default'].createElement(antd_1.Reset, {
          key: 'reset',
          size: size
        }, "\u91CD\u7F6E"),
        button: btn.children
      };
      return _component[btn.htmlType];
    })) : null;
  };

  var SchemaField = react_2.createSchemaField({
    components: __assign({
      Input: antd_1.Input,
      FormItem: antd_1.FormItem,
      FormLayout: antd_1.FormLayout,
      Select: antd_1.Select,
      RadioGroup: RadioGroup,
      TextArea: TextArea,
      Switch: antd_1.Switch,
      CheckboxGroup: CheckboxGroup,
      NumberPicker: antd_1.NumberPicker,
      FormGrid: antd_1.FormGrid,
      WeekRangePicker: YDatePicker_1.WeekRangePicker,
      DateRangePicker: YDatePicker_1.DateRangePicker,
      MonthRangePicker: YDatePicker_1.MonthRangePicker,
      MonthPicker: YDatePicker_1.MonthPicker,
      WeekPicker: YDatePicker_1.WeekPicker,
      DatePicker: YDatePicker_1.DatePicker,
      DateTimeRangePicker: YDatePicker_1.DateTimeRangePicker,
      DateTimePicker: YDatePicker_1.DateTimePicker,
      ArrayTable: YArrayTable_1['default']
    }, customComponent)
  });
  return react_1['default'].createElement('div', __assign({}, others), react_1['default'].createElement(react_2.FormProvider, {
    form: form
  }, react_1['default'].createElement(antd_1.FormLayout, __assign({}, layoutProps, {
    size: size
  }), react_1['default'].createElement(SchemaField, {
    schema: getItemsSchema(),
    scope: {
      useAsyncDataSource: hook_1.useAsyncDataSource,
      dataSource: dataSource
    }
  }), buttonsProps.sticky ? react_1['default'].createElement(antd_1.FormButtonGroup.Sticky, {
    align: buttonsProps.align
  }, renderButtons()) : renderButtons())));
}

YwJsonForm.defaultProps = {
  form: null,
  layoutProps: {
    // labelAlign: 'right',
    labelCol: 6,
    wrapperCol: 10,
    fullness: false
  },
  buttons: [{
    htmlType: 'submit'
  }],
  buttonsProps: {},
  onSubmit: function onSubmit(form) {
    console.log('submit', form);
  },
  onCreate: function onCreate(form) {// console.log('表单初始化', form)
    // form.setInitialValues({ input: 123333 })
  },
  onValueChange: function onValueChange(data, form) {
    console.log('change', form.getValuesIn('arrayTable')); // form.setInitialValues({ input: 123333 })
  }
};
YwJsonForm.displayName = 'YwJsonForm';
exports['default'] = YwJsonForm;