import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["CustomComponent"],
    _excluded2 = ["buttons", "onCreate", "onSubmit", "editable", "disabled", "size", "layoutProps", "buttonsProps", "items", "initialValues", "onValueChange", "linkages"],
    _excluded3 = ["type", "conditions", "target"];
import React, { useMemo, Fragment, useEffect } from 'react';
import { createForm, onFormInit, onFormValuesChange, onFieldReact, registerValidateRules, registerValidateFormats } from '@formily/core';
import { FormButtonGroup, Submit, Reset, FormLayout, PreviewText } from '@formily/antd';
import jsonLogic from 'json-logic-js';
import { isObject, formatOptionsList } from "../../utils";
import { FormProvider, createSchemaField, useField, useFieldSchema } from '@formily/react';
import YwTitle from "../YwTitle";
import { useAsyncDataSource } from "./hook";
import { FORMATS, RULES } from "./rules";
import styles from "./index.module.less";
import * as COMPS from "./components";
var dataSource = {};
registerValidateFormats(FORMATS);
registerValidateRules(RULES);

var customComponent = function customComponent(props) {
  var field = useField();
  var schema = useFieldSchema();

  var _ref = schema['x-component-props'] || {},
      CustomComponent = _ref.CustomComponent,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded);

  return CustomComponent && /*#__PURE__*/React.createElement(CustomComponent, _extends({}, rest, {
    field: field
  }));
};

export var SchemaField = createSchemaField({
  components: _extends({}, COMPS)
});

var formatSchema = function formatSchema(item) {
  var _item$componentProps, _item$componentProps2, _item$componentProps3, _item$componentProps4;

  if (item === void 0) {
    item = {};
  }

  // if (item.customComponent) {
  //   customComponent = [...customComponent, item.customComponent];
  // }
  var options = item["enum"] || formatOptionsList((_item$componentProps = item.componentProps) === null || _item$componentProps === void 0 ? void 0 : _item$componentProps.dataSource, (_item$componentProps2 = item.componentProps) === null || _item$componentProps2 === void 0 ? void 0 : _item$componentProps2.fieldNames) || formatOptionsList((_item$componentProps3 = item.componentProps) === null || _item$componentProps3 === void 0 ? void 0 : _item$componentProps3.dict, {
    label: 'dictName',
    value: 'dictValue'
  });

  if (item.getDataSource) {
    dataSource[item.name] = item.getDataSource;
  }

  return _extends({
    type: item.type || 'string',
    title: item.title,
    description: item.description,
    "default": item.defaultValue,
    readOnly: item.readOnly,
    "enum": options,
    required: item.required,
    'x-validator': item.rules,
    'x-decorator': item.decorator || 'FormItem',
    'x-decorator-props': _extends({}, item.props, {
      colon: false
    }),
    'x-reactions': item.reactions
  }, item.getDataSource ? {
    'x-reactions': ['{{useAsyncDataSource(dataSource)}}']
  } : {}, (_item$componentProps4 = item.componentProps) !== null && _item$componentProps4 !== void 0 && _item$componentProps4.getDataSource && item.component !== 'SearchSelect' ? {
    'x-reactions': ['{{useAsyncDataSource()}}']
  } : {}, {
    'x-component': item.customComponent ? customComponent : item.component,
    'x-component-props': _extends({
      allowClear: !item.required
    }, item.componentProps, item.customComponent ? {
      CustomComponent: item.customComponent
    } : {}),
    'x-visible': item.visible,
    'x-disabled': item.disabled,
    'x-read-pretty': item.preview
  });
};

function YwJsonForm(props) {
  var buttons = props.buttons,
      onCreate = props.onCreate,
      onSubmit = props.onSubmit,
      editable = props.editable,
      disabled = props.disabled,
      size = props.size,
      layoutProps = props.layoutProps,
      buttonsProps = props.buttonsProps,
      items = props.items,
      initialValues = props.initialValues,
      onValueChange = props.onValueChange,
      linkages = props.linkages,
      others = _objectWithoutPropertiesLoose(props, _excluded2);

  var form = props.form || useMemo(function () {
    return createForm({
      disabled: disabled,
      editable: editable,
      effects: function effects(form) {
        onFormInit(function () {
          onCreate(form);
        });
        onFormValuesChange(function (value) {
          onValueChange(form.values, form);
        });
      }
    });
  }, []);

  var FormGroup = function FormGroup(props) {
    var field = useField();
    return /*#__PURE__*/React.createElement(Fragment, null, /*#__PURE__*/React.createElement(YwTitle, _extends({
      size: props.size,
      text: props.text
    }, field.componentProps)), /*#__PURE__*/React.createElement(FormLayout, _extends({}, layoutProps, {
      size: size === 'middle' ? 'default' : size,
      style: {
        marginTop: '20px'
      }
    }), props.children));
  };

  var getItemsSchema = function getItemsSchema() {
    var formatItem = function formatItem(nodeList) {
      if (nodeList.length === 0) {
        return null;
      }

      var res = {};
      nodeList.forEach(function (item, idx) {
        if (item.component === 'FormGroup') {
          // 分组标题
          res["NO_FIELD_NAME_" + idx] = _extends({
            type: 'void',
            'x-component': FormGroup,
            'x-decorator': 'FormItem',
            'x-visible': item.visible,
            'x-component-props': _extends({
              size: size === 'small' ? 's' : 'm',
              text: item.title
            }, item.componentProps || {})
          }, item.children ? formatItem(item.children) : {});
        } else if (item.component === 'FormGrid') {
          // grid
          res["NO_FIELD_NAME_" + idx] = _extends({}, formatSchema(item), {
            type: 'void'
          }, item.children ? formatItem(item.children) : {});
        } else if (['ArrayTable', 'ArrayItems'].includes(item.component)) {
          // ArrayTable
          res["NO_FIELD_NAME_" + idx] = _extends({}, formatSchema(item), {
            type: 'array',
            'x-component-props': _extends({}, item.componentProps, {
              name: item.name,
              layoutProps: layoutProps,
              arrayConfig: item.children
            }),
            'x-decorator-props': _extends({}, formatSchema(item)['x-decorator-props'])
          }); // } else if (item.component === 'ArrayItems') {
          //   // ArrayTable
          //   res[`NO_FIELD_NAME_${idx}`] = {
          //     ...formatSchema(item),
          //     type: 'array',
          //     'x-component-props': {
          //       ...item.componentProps,
          //       name: item.name,
          //       layoutProps,
          //       arrayConfig: item.children,
          //     },
          //   };
        } else {
          res[item.name || "NO_FIELD_NAME_" + idx] = _extends({}, formatSchema(item), item.children ? formatItem(item.children) : {});
        }
      });
      return {
        properties: res
      };
    };

    return formatItem(items || []);
  };

  var renderButtons = function renderButtons() {
    return buttons !== null && buttons !== void 0 && buttons.length ? /*#__PURE__*/React.createElement(FormButtonGroup.FormItem, null, buttons === null || buttons === void 0 ? void 0 : buttons.map(function (btn) {
      var _component = {
        submit: /*#__PURE__*/React.createElement(Submit, {
          key: "submit",
          onSubmit: onSubmit,
          size: size
        }, "\u63D0\u4EA4"),
        reset: /*#__PURE__*/React.createElement(Reset, {
          key: "reset",
          size: size
        }, "\u91CD\u7F6E"),
        button: btn.children
      };
      return _component[btn.htmlType];
    })) : null;
  };

  var valueChangeforLink = function valueChangeforLink(linkages) {
    if (linkages === void 0) {
      linkages = [];
    }

    var isExecute = function isExecute(conditions, field, form) {
      if (conditions === void 0) {
        conditions = [];
      }

      if (isObject(conditions)) {
        return jsonLogic.apply(conditions, form.getValuesIn());
      } else if (!conditions.length) {
        return true;
      } else {
        return conditions.every(function (_ref2) {
          var key = _ref2.key,
              value = _ref2.value;
          return field.query(key).value() === value;
        });
      }
    };

    linkages.forEach(function (_ref3, idx) {
      var type = _ref3.type,
          conditions = _ref3.conditions,
          target = _ref3.target,
          rest = _objectWithoutPropertiesLoose(_ref3, _excluded3);

      if (type === 'value') {
        form.addEffects(type + "-" + target + "-" + idx, function (form) {
          onFieldReact(target, function (field) {
            if (isExecute(conditions, field, form)) {
              field.setValue(rest.targetValue);
            } else {
              field.setValue(field.initialValue);
            }
          });
        });
      } else if (type === 'disabled') {
        form.addEffects(type + "-" + target + "-" + idx, function (form) {
          onFieldReact(target, function (field) {
            if (isExecute(conditions, field, form)) {
              field.setState({
                disabled: rest.targetValue
              });
            } else {
              field.setState({
                disabled: !rest.targetValue
              });
            }
          });
        });
      } else if (type === 'visible') {
        form.addEffects(type + "-" + target + "-" + idx, function (form) {
          onFieldReact(target, function (field) {
            if (isExecute(conditions, field, form)) {
              field.setState({
                visible: rest.targetValue
              });
            } else {
              field.setState({
                visible: !rest.targetValue
              });
            }
          });
        });
      } else if (type === 'enum') {
        form.addEffects(type + "-" + target + "-" + idx, function (form) {
          onFieldReact(target, function (field) {
            if (isExecute(conditions, field, form)) {
              field.setState({
                dataSource: rest.targetValue
              });
              field.setValue('');
            } else {
              field.setState({
                dataSource: field.dataSource
              });
            }
          });
        });
      }
    });
  };

  useEffect(function () {
    linkages && valueChangeforLink(linkages);
  }, []);
  useEffect(function () {
    initialValues && form.setValues(initialValues);
  }, [initialValues]);
  return /*#__PURE__*/React.createElement("div", {
    className: styles['yw-json-form'],
    style: props.style
  }, /*#__PURE__*/React.createElement(FormProvider, {
    form: form
  }, /*#__PURE__*/React.createElement(PreviewText.Placeholder, {
    value: "\u6682\u65E0\u6570\u636E"
  }, /*#__PURE__*/React.createElement(FormLayout, _extends({}, layoutProps, {
    size: size === 'middle' ? 'default' : size
  }), /*#__PURE__*/React.createElement(SchemaField, {
    schema: getItemsSchema(),
    scope: {
      useAsyncDataSource: useAsyncDataSource,
      dataSource: dataSource
    }
  }), buttonsProps.sticky ? /*#__PURE__*/React.createElement(FormButtonGroup.Sticky, {
    align: buttonsProps.align
  }, renderButtons()) : renderButtons()))));
}

YwJsonForm.defaultProps = {
  form: null,
  layoutProps: {
    // labelAlign: 'right',
    fullness: false,
    labelCol: 6,
    wrapperCol: 10 // inset: true,
    // inline: true,
    // layout:['vertical', 'horizontal','inline'],

  },
  buttons: [{
    htmlType: 'submit'
  }, {
    htmlType: 'reset'
  }],
  buttonsProps: {},
  onSubmit: function onSubmit(form) {
    console.log('submit', form);
  },
  onCreate: function onCreate(form) {// console.log('表单初始化', form)
    // form.setInitialValues({ input: 123333 })
  },
  onValueChange: function onValueChange(data, form) {// form.setInitialValues({ input: 123333 });
  }
}; // YwJsonForm.displayName = 'YwJsonForm';

export { YwJsonForm };