import React, { useState, useMemo } from 'react';
import styles from "./index.module.less";
import { Button } from 'antd';
import { StatusTypeIcon, isArray } from "../../utils/index";
import { CloseOutlined } from '@ant-design/icons';
export default function YwNotice(props) {
  var type = props.type,
      className = props.className,
      style = props.style,
      title = props.title,
      content = props.content,
      icon = props.icon,
      closeable = props.closeable,
      btnText = props.btnText,
      onClick = props.onClick;

  var _useState = useState(true),
      visible = _useState[0],
      setVisible = _useState[1];

  var isInline = useMemo(function () {
    return title && !content;
  }, [title, content]);
  var isNormal = useMemo(function () {
    return title && content && !isArray(content);
  }, [title, content]);
  var isMultiple = useMemo(function () {
    return !title && isArray(content);
  }, [title, content]);

  var renderInline = function renderInline() {
    if (!visible) return null;
    return /*#__PURE__*/React.createElement("div", {
      className: styles["yw-notice"] + " " + styles["yw-notice-" + type] + " " + styles["yw-notice-inline"] + " " + className,
      style: style
    }, /*#__PURE__*/React.createElement("div", {
      className: styles["yw-notice-container"]
    }, /*#__PURE__*/React.createElement("i", {
      className: styles['yw-notice-icon']
    }, icon || StatusTypeIcon[type]), /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("div", {
      className: styles['yw-notice-title']
    }, title))), renderButton(), renderCloseIcon());
  };

  var renderNormal = function renderNormal() {
    if (!visible) return null;
    return /*#__PURE__*/React.createElement("div", {
      className: styles["yw-notice"] + " " + styles["yw-notice-" + type] + " " + className,
      style: style
    }, /*#__PURE__*/React.createElement("div", {
      className: styles["yw-notice-container"]
    }, /*#__PURE__*/React.createElement("i", {
      className: styles['yw-notice-icon']
    }, icon || StatusTypeIcon[type]), /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("div", {
      className: styles['yw-notice-title']
    }, title), /*#__PURE__*/React.createElement("div", {
      className: styles['yw-notice-content']
    }, content))), renderButton(), renderCloseIcon());
  };

  var renderMultiple = function renderMultiple() {
    if (!visible) return null;
    return /*#__PURE__*/React.createElement("div", {
      className: styles["yw-notice"] + " " + styles["yw-notice-" + type] + " " + className,
      style: style
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        flex: 1
      }
    }, content.map(function (v) {
      return /*#__PURE__*/React.createElement("div", {
        key: v,
        className: styles['yw-notice-line']
      }, /*#__PURE__*/React.createElement("i", {
        className: styles['yw-notice-icon']
      }, icon || StatusTypeIcon[type]), /*#__PURE__*/React.createElement("div", {
        key: v,
        className: styles['yw-notice-content']
      }, v));
    })), renderButton(), renderCloseIcon());
  };

  var renderCloseIcon = function renderCloseIcon() {
    return closeable && /*#__PURE__*/React.createElement(CloseOutlined, {
      style: {
        fontSize: '12px',
        color: '#ccc',
        marginLeft: '12px'
      },
      onClick: function onClick() {
        setVisible(false);
        onClose();
      }
    });
  };

  var renderButton = function renderButton() {
    if (!btnText) return null;
    return /*#__PURE__*/React.createElement(Button, {
      size: "small",
      type: "link",
      className: styles['yw-notice-btn'],
      onClick: onClick
    }, btnText);
  };

  return /*#__PURE__*/React.createElement(React.Fragment, null, isInline && renderInline(), isNormal && renderNormal(), isMultiple && renderMultiple());
}
YwNotice.defaultProps = {
  type: 'notice',
  icon: null,
  content: '',
  title: '',
  closeable: false,
  btnText: '',
  onClick: function onClick() {},
  onClose: function onClose() {}
};