import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["component", "componentProps", "formatValues"],
    _excluded2 = ["columns", "buttons", "getTableData", "filterProps", "tableType", "showTotal", "renderTotal"],
    _excluded3 = ["children"];
import React, { useState, useRef, useEffect, useMemo, useImperativeHandle } from 'react';
import { Table, Checkbox, Dropdown, Menu, ConfigProvider } from 'antd';
import zhCN from 'antd/es/locale/zh_CN';
import styles from "./index.module.less";
import { Person, Time, Status, Operates, Tags, MultipleCol, CopyCol, IndexCol } from "./components/index";
import { DetailInfo, Price, LongText2Ellipsis } from "./components/detailInfo";
import usePagination from "./usePagination";
import { isVisible, isDisabled, isObject, isFunction } from "../../utils/index";
import YwButton from "../YwButton";
import VirtualTable from "./virtual";
import { DownIcon } from "../common/icon";
var registerCom = {
  MultipleCol: MultipleCol,
  Time: Time,
  Person: Person,
  Status: Status,
  Operates: Operates,
  Tags: Tags,
  DetailInfo: DetailInfo,
  Price: Price,
  CopyCol: CopyCol,
  IndexCol: IndexCol,
  LongText2Ellipsis: LongText2Ellipsis
};

var formatColumns = function formatColumns(_columns, _ref) {
  if (_columns === void 0) {
    _columns = [];
  }

  var reload = _ref.reload,
      group = _ref.group;
  return _columns.map(function (_ref2) {
    var _ref2$component = _ref2.component,
        component = _ref2$component === void 0 ? '' : _ref2$component,
        componentProps = _ref2.componentProps,
        _ref2$formatValues = _ref2.formatValues,
        formatValues = _ref2$formatValues === void 0 ? null : _ref2$formatValues,
        item = _objectWithoutPropertiesLoose(_ref2, _excluded);

    if (!component) return _extends({}, item, {
      colSpan: group ? 0 : 1
    });
    return _extends({}, item, {
      colSpan: group ? 0 : 1,
      render: function render(data, record, index) {
        var Component = registerCom[component] || null;

        if (formatValues) {
          var value = formatValues(data, record, index);
          return /*#__PURE__*/React.createElement(Component, _extends({
            value: value
          }, componentProps, {
            record: record,
            key: item.dataIndex
          }));
        }

        return /*#__PURE__*/React.createElement(Component, _extends({
          value: data
        }, componentProps, {
          record: record,
          index: index,
          reload: reload,
          key: item.dataIndex
        }));
      }
    });
  });
};

var formatBatchBtn = function formatBatchBtn(buttons, _ref3) {
  if (buttons === void 0) {
    buttons = [];
  }

  var hasSelect = _ref3.hasSelect,
      selectedRowKeys = _ref3.selectedRowKeys,
      selectedData = _ref3.selectedData,
      reload = _ref3.reload;
  return buttons.filter(function (v) {
    return v.type === 'batch' || v.type === 'left';
  }).map(function (v, i) {
    return v.children || /*#__PURE__*/React.createElement(YwButton, _extends({}, v, {
      visible: isVisible(v.visible, null),
      disabled: !hasSelect || isDisabled(v.disabled, null),
      onClick: function onClick() {
        v.onClick(selectedRowKeys, selectedData, reload);
      }
    }));
  });
};

var formatFilter = function formatFilter(buttons, _ref4) {
  if (buttons === void 0) {
    buttons = [];
  }

  var reload = _ref4.reload,
      _ref4$innerFilter = _ref4.innerFilter,
      innerFilter = _ref4$innerFilter === void 0 ? {} : _ref4$innerFilter,
      updateInnerFilter = _ref4.updateInnerFilter;
  return buttons.filter(function (v) {
    return v.type === 'filter' && isVisible(v.visible, null);
  }).map(function (v, i) {
    return v.children || /*#__PURE__*/React.createElement(Checkbox, {
      disabled: isDisabled(v.disabled, null),
      defaultChecked: v.defaultValue || false,
      checked: innerFilter[v.name],
      onChange: function onChange(e) {
        var _updateInnerFilter;

        v.name && updateInnerFilter((_updateInnerFilter = {}, _updateInnerFilter[v.name] = e.target.checked, _updateInnerFilter)); // v.onChange && v.onChange(e.target.checked);
        // v.onClick(selectedRowKeys, selectedData, reload);
      }
    }, v.btnText);
  });
};

var formatActionBtn = function formatActionBtn(buttons, _ref5) {
  if (buttons === void 0) {
    buttons = [];
  }

  var reload = _ref5.reload;
  return buttons.filter(function (v) {
    return v.type !== 'batch' && v.type !== 'left' && v.type !== 'filter';
  }).map(function (_ref6, i) {
    var v = _extends({}, _ref6);

    if (v.btnType === 'dropdown') {
      var _v$dataSource;

      var menu = /*#__PURE__*/React.createElement(Menu, {
        onClick: function onClick(data) {
          v.onClick(data, reload);
        }
      }, (_v$dataSource = v.dataSource) === null || _v$dataSource === void 0 ? void 0 : _v$dataSource.map(function (_ref7) {
        var key = _ref7.key,
            label = _ref7.label;
        return /*#__PURE__*/React.createElement(Menu.Item, {
          key: key
        }, label);
      }));
      return /*#__PURE__*/React.createElement(Dropdown, {
        overlay: menu
      }, /*#__PURE__*/React.createElement(YwButton, _extends({}, v, {
        visible: isVisible(v.visible, null),
        disabled: isDisabled(v.disabled, null),
        rightIcon: /*#__PURE__*/React.createElement(DownIcon, {
          style: {
            marginLeft: '6px'
          }
        })
      })));
    }

    return v.children || /*#__PURE__*/React.createElement(YwButton, _extends({}, v, {
      visible: isVisible(v.visible, null),
      disabled: isDisabled(v.disabled, null),
      onClick: function onClick() {
        v.onClick(reload);
      }
    }));
  });
};

var BaseTable = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var useVirtual = props.useVirtual; // return <Table {...props} />

  return useVirtual ? /*#__PURE__*/React.createElement(VirtualTable, _extends({
    ref: ref,
    scroll: {
      y: 300
    }
  }, props)) : /*#__PURE__*/React.createElement(Table, _extends({
    ref: ref
  }, props));
});
var YwTable = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var _props$rowSelection, _props$pagination, _props$rowSelection2, _props$rowSelection3;

  var columns = props.columns,
      buttons = props.buttons,
      getTableData = props.getTableData,
      filterProps = props.filterProps,
      tableType = props.tableType,
      showTotal = props.showTotal,
      renderTotal = props.renderTotal,
      others = _objectWithoutPropertiesLoose(props, _excluded2);

  var baseTableRef = useRef();

  var _useState = useState(((_props$rowSelection = props.rowSelection) === null || _props$rowSelection === void 0 ? void 0 : _props$rowSelection.selectedRowKeys) || []),
      selectedRowKeys = _useState[0],
      setSelectedRowKeys = _useState[1];

  var hasPagination = useMemo(function () {
    return isObject(props.pagination);
  }, [props.pagination]);

  var _useState2 = useState([]),
      selectedData = _useState2[0],
      setSelectedData = _useState2[1];

  var rowSelection = useMemo(function () {
    return props.rowSelection ? _extends({
      selectedRowKeys: selectedRowKeys
    }, props.rowSelection, {
      onChange: function onChange(newSelectedRowKeys, data, info) {
        setSelectedRowKeys(newSelectedRowKeys);
        setSelectedData(data);
        isFunction(props.rowSelection.onChange) && props.rowSelection.onChange(newSelectedRowKeys, data, info);
      }
    }) : null;
  }, [props.rowSelection, selectedRowKeys]);
  var hasSelect = useMemo(function () {
    return !!(selectedRowKeys.length > 0);
  }, [selectedRowKeys]);

  var _usePagination = usePagination(function (_ref8, params) {
    var pageIndex = _ref8.pageIndex,
        pageSize = _ref8.pageSize;
    return getTableData(_extends({}, hasPagination ? {
      pageIndex: pageIndex
    } : {}, hasPagination ? {
      pageSize: pageSize
    } : {}, params));
  }, _extends({}, hasPagination ? {
    defaultPageSize: ((_props$pagination = props.pagination) === null || _props$pagination === void 0 ? void 0 : _props$pagination.pageSize) || 20
  } : {}, {
    manual: true
  })),
      data = _usePagination.data,
      loading = _usePagination.loading,
      pagination = _usePagination.pagination,
      run = _usePagination.run,
      params = _usePagination.params;

  useEffect(function () {
    refresh();
  }, [filterProps]);

  var reload = function reload() {
    setSelectedRowKeys([]);
    setSelectedData([]);
    run(params[0] || {}, params[1] || {});
  };

  var refresh = function refresh() {
    var _params$, _props$pagination2;

    setSelectedRowKeys([]);
    setSelectedData([]);
    run({
      pageIndex: 1,
      pageSize: ((_params$ = params[0]) === null || _params$ === void 0 ? void 0 : _params$.pageSize) || ((_props$pagination2 = props.pagination) === null || _props$pagination2 === void 0 ? void 0 : _props$pagination2.pageSize) || 20
    }, filterProps);
  };

  useImperativeHandle(ref, function () {
    var _baseTableRef$current;

    return {
      reload: reload,
      scrollTo: baseTableRef === null || baseTableRef === void 0 ? void 0 : (_baseTableRef$current = baseTableRef.current) === null || _baseTableRef$current === void 0 ? void 0 : _baseTableRef$current.scrollTo,
      refresh: refresh
    };
  });

  var renderDefaultTable = function renderDefaultTable() {
    return {
      columns: formatColumns(columns, {
        reload: reload
      }),
      dataSource: (data === null || data === void 0 ? void 0 : data.list) || others.dataSource || [],
      rowSelection: rowSelection
    };
  };

  var renderGroupTable = function renderGroupTable() {
    var dataSource = (data === null || data === void 0 ? void 0 : data.list) || others.dataSource || [];
    return {
      rowClassName: 'group-container-row',
      className: styles['yw-group-table'],
      rowSelection: props.rowSelection ? _extends({}, props.rowSelection, {
        onSelectAll: function onSelectAll(selected, selectedRows, data) {
          if (selected) {
            var _dataSource$reduce;

            setSelectedData(dataSource.reduce(function (curr, prev) {
              return [].concat(curr, prev.children);
            }, []));
            setSelectedRowKeys(dataSource === null || dataSource === void 0 ? void 0 : (_dataSource$reduce = dataSource.reduce(function (curr, prev) {
              return [].concat(curr, prev.children);
            }, [])) === null || _dataSource$reduce === void 0 ? void 0 : _dataSource$reduce.map(function (v) {
              return v[props.rowKey || 'id'];
            }));
          } else {
            setSelectedData([]);
            setSelectedRowKeys([]);
          }
        }
      }) : null,
      columns: columns === null || columns === void 0 ? void 0 : columns.map(function (v, i) {
        if (i === 0) {
          return _extends({}, v, {
            onCell: function onCell(_, index) {
              return {
                colspan: columns.length + 1
              };
            },
            dataIndex: 'groupItem',
            render: function render(groupItem, record) {
              if (groupItem === void 0) {
                groupItem = [];
              }

              return /*#__PURE__*/React.createElement(Table, _extends({}, others, {
                title: others.renderGroupTitle,
                showHeader: false,
                columns: formatColumns(columns, {
                  reload: reload
                }),
                dataSource: groupItem,
                loading: false,
                rowSelection: props.rowSelection ? _extends({}, props.rowSelection, {
                  selectedRowKeys: selectedRowKeys,
                  onSelect: function onSelect(selected, selectedRows, changeRows) {
                    if (selectedRows) {
                      setSelectedRowKeys([].concat(selectedRowKeys, [selected[props.rowKey]]));
                      setSelectedData([].concat(selectedData, [selected]));
                    } else {
                      setSelectedRowKeys([].concat(selectedRowKeys === null || selectedRowKeys === void 0 ? void 0 : selectedRowKeys.filter(function (v) {
                        return v !== selected[props.rowKey];
                      })));
                      setSelectedData([].concat(selectedData === null || selectedData === void 0 ? void 0 : selectedData.filter(function (v) {
                        return v[props.rowKey] !== selected[props.rowKey];
                      })));
                    }
                  }
                }) : null,
                pagination: false
              }));
            }
          });
        } else {
          return _extends({}, v, {
            onCell: function onCell(_, index) {
              return {
                colspan: 0
              };
            }
          });
        }
      }),
      dataSource: dataSource.map(function (_ref9) {
        var children = _ref9.children,
            v = _objectWithoutPropertiesLoose(_ref9, _excluded3);

        return _extends({}, v, {
          groupItem: children
        });
      })
    };
  };

  var renderTableProps = function renderTableProps(tableType) {
    if (tableType === 'default') return renderDefaultTable();
    if (tableType === 'group') return renderGroupTable();
    return {};
  };

  return /*#__PURE__*/React.createElement(ConfigProvider, {
    locale: zhCN
  }, /*#__PURE__*/React.createElement("div", {
    className: styles['yw-table'] + " " + styles['yw-table-multiple'],
    style: props.style
  }, /*#__PURE__*/React.createElement("div", {
    className: styles["yw-table-btns"]
  }, /*#__PURE__*/React.createElement("div", {
    className: styles.batch
  }, (showTotal || renderTotal) && pagination && !!(selectedRowKeys.length === 0) ? /*#__PURE__*/React.createElement("span", {
    className: styles.total
  }, renderTotal ? renderTotal(pagination === null || pagination === void 0 ? void 0 : pagination.total) : "\u5171 " + ((pagination === null || pagination === void 0 ? void 0 : pagination.total) || 0) + " \u6761 ") : null, selectedRowKeys.length > 0 && !((_props$rowSelection2 = props.rowSelection) !== null && _props$rowSelection2 !== void 0 && _props$rowSelection2.hideSelectTotal) && ((_props$rowSelection3 = props.rowSelection) === null || _props$rowSelection3 === void 0 ? void 0 : _props$rowSelection3.type) !== 'radio' && /*#__PURE__*/React.createElement("span", {
    className: styles.total
  }, "\u5171\u9009\u4E2D ", selectedRowKeys.length, " \u6761 "), formatBatchBtn(buttons, {
    hasSelect: hasSelect,
    selectedRowKeys: selectedRowKeys,
    selectedData: selectedData,
    reload: reload
  })), !!buttons.length && /*#__PURE__*/React.createElement("div", {
    className: styles.action
  }, formatActionBtn(buttons, {
    reload: reload
  }))), /*#__PURE__*/React.createElement(BaseTable, _extends({}, others, {
    ref: baseTableRef,
    loading: loading,
    onChange: function onChange(pagination, filters, sorter, extra) {
      if (extra.action === 'paginate') {
        // 分页时清空
        setSelectedRowKeys([]);
        setSelectedData([]);
        return;
      }

      props.onChange && props.onChange(pagination, filters, sorter, extra);
    },
    pagination: hasPagination ? _extends({}, props.pagination, pagination) : props.pagination // rowSelection={rowSelection}

  }, renderTableProps(tableType)))));
});
YwTable.defaultProps = {
  // multiple: true,
  // stickyHeader: false,
  // composite: true,
  pagination: {},
  buttons: [],
  rowSelection: null,
  columns: [],
  tableType: 'default',
  showTotal: false,
  filterProps: {},
  rowHeight: 100,
  getTableData: function getTableData(props) {
    return null;
  },
  renderGroupTitle: function renderGroupTitle(record) {
    return null;
  }
};
export default YwTable;