import _extends from "@babel/runtime/helpers/extends";
import React, { useState, useRef, useEffect, useImperativeHandle } from 'react';
import ResizeObserver from 'rc-resize-observer';
import { VariableSizeGrid as Grid } from 'react-window';
import { Table } from 'antd';
import styles from "./index.module.less";
var VirtualTable = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var columns = props.columns,
      scroll = props.scroll,
      _props$rowHeight = props.rowHeight,
      _rowHeight = _props$rowHeight === void 0 ? 100 : _props$rowHeight;

  var _useState = useState(0),
      tableWidth = _useState[0],
      setTableWidth = _useState[1];

  var widthColumnCount = columns === null || columns === void 0 ? void 0 : columns.filter(function (_ref) {
    var width = _ref.width;
    return !width;
  }).length;
  var mergedColumns = columns === null || columns === void 0 ? void 0 : columns.map(function (column) {
    if (column.width) {
      return column;
    }

    return _extends({}, column, {
      width: Math.floor(tableWidth / widthColumnCount)
    });
  });
  var gridRef = useRef();

  var _useState2 = useState(function () {
    var obj = {};
    Object.defineProperty(obj, 'scrollLeft', {
      get: function get() {
        if (gridRef.current) {
          var _gridRef$current, _gridRef$current$stat;

          return (_gridRef$current = gridRef.current) === null || _gridRef$current === void 0 ? void 0 : (_gridRef$current$stat = _gridRef$current.state) === null || _gridRef$current$stat === void 0 ? void 0 : _gridRef$current$stat.scrollLeft;
        }

        return null;
      },
      set: function set(scrollLeft) {
        if (gridRef.current) {
          gridRef.current.scrollTo({
            scrollLeft: scrollLeft
          });
        }
      }
    });
    return obj;
  }),
      connectObject = _useState2[0];

  var resetVirtualGrid = function resetVirtualGrid() {
    var _gridRef$current2;

    (_gridRef$current2 = gridRef.current) === null || _gridRef$current2 === void 0 ? void 0 : _gridRef$current2.resetAfterIndices({
      columnIndex: 0,
      shouldForceUpdate: true
    });
  };

  var scrollTo = function scrollTo(props) {
    var _gridRef$current3;

    (_gridRef$current3 = gridRef.current) === null || _gridRef$current3 === void 0 ? void 0 : _gridRef$current3.scrollTo(props);
  };

  useImperativeHandle(ref, function () {
    return {
      scrollTo: scrollTo
    };
  });
  useEffect(function () {
    return resetVirtualGrid;
  }, [tableWidth]);

  var renderVirtualList = function renderVirtualList(rawData, _ref2) {
    var scrollbarSize = _ref2.scrollbarSize,
        ref = _ref2.ref,
        _onScroll = _ref2.onScroll;
    ref.current = connectObject;
    var totalHeight = rawData.length * _rowHeight;
    return /*#__PURE__*/React.createElement(Grid, {
      ref: gridRef,
      className: "virtual-grid",
      columnCount: mergedColumns.length,
      columnWidth: function columnWidth(index) {
        var width = mergedColumns[index].width;
        return totalHeight > scroll.y && index === mergedColumns.length - 1 ? width - scrollbarSize - 1 : width;
      },
      height: scroll.y,
      rowCount: rawData.length,
      rowHeight: function rowHeight() {
        return _rowHeight;
      },
      width: tableWidth,
      onScroll: function onScroll(_ref3) {
        var scrollLeft = _ref3.scrollLeft,
            scrollTop = _ref3.scrollTop;

        _onScroll({
          scrollLeft: scrollLeft,
          scrollTop: scrollTop
        });

        props.onScroll && props.onScroll({
          scrollLeft: scrollLeft,
          scrollTop: scrollTop
        });
      }
    }, function (_ref4) {
      var columnIndex = _ref4.columnIndex,
          rowIndex = _ref4.rowIndex,
          style = _ref4.style;
      var render = mergedColumns[columnIndex].render;
      return /*#__PURE__*/React.createElement("div", {
        className: styles['virtual-table-cell'] + " " + (columnIndex === mergedColumns.length - 1 ? 'virtual-table-cell-last' : '') // className={classNames('virtual-table-cell', {
        //   'virtual-table-cell-last': columnIndex === mergedColumns.length - 1,
        // })}
        ,
        style: style
      }, render ? render(rawData[rowIndex][mergedColumns[columnIndex].dataIndex], rawData[rowIndex], rowIndex) : rawData[rowIndex][mergedColumns[columnIndex].dataIndex]);
    });
  };

  return /*#__PURE__*/React.createElement(ResizeObserver, {
    onResize: function onResize(_ref5) {
      var width = _ref5.width;
      setTableWidth(width);
    }
  }, /*#__PURE__*/React.createElement(Table, _extends({}, props, {
    className: "virtual-table",
    columns: mergedColumns,
    pagination: false,
    components: {
      body: renderVirtualList
    }
  })));
});
export default VirtualTable;