import type { Form } from '@formily/core';
import type { ISchema, SchemaEnum, SchemaTypes } from '@formily/react';
import type { TabsProps, TableProps, PaginationProps, ButtonProps, ModalProps, DrawerProps, TooltipProps, ListProps, TagProps } from 'antd';
import { TableRowSelection } from 'antd/lib/table/interface';
import { ReactNode } from 'react';
export declare type Dict = {
    dictName: string;
    dictValue: number;
    extParams?: any;
    subList?: any;
};
declare type checkData = {
    value?: string;
    label?: string;
    disabled?: boolean;
    checkboxDisabled?: boolean;
    children?: Array<checkData>;
    [propName: string]: any;
};
export declare type SizeType = 'small' | 'middle' | 'large' | undefined;
export interface YwTitleProps {
    /** 主标题内容 */
    text: string;
    /** 副标题 */
    subtitle?: string;
    /** 标题尺寸 */
    size?: 'l' | 'm' | 's';
    /** 自定义内容 */
    children?: React.ReactNode;
    /** 样式 */
    style?: React.CSSProperties;
}
export declare type TabItem = {
    tab: string;
    key: string;
    content?: string | React.ReactNode;
    /** 红点提示 */
    dot?: boolean;
    /** 数量提示 */
    count?: number;
};
export interface YwTabProps extends Pick<TabsProps, 'type' | 'renderTabBar' | 'onChange' | 'activeKey' | 'destroyInactiveTabPane' | 'tabBarExtraContent'> {
    /** 样式 */
    style?: React.CSSProperties;
    /** 形态 ，默认pure */
    shape?: 'pure' | 'wrapped' | 'capsule';
    /** tab项 */
    dataSource: Array<TabItem>;
    children?: ReactNode;
}
export declare type ColumnItem = {
    /** 标题 */
    title: string | React.ReactNode;
    dataIndex: string;
    width?: number;
    /** 组件 */
    component?: 'MultipleCol' | 'Time' | 'Person' | 'Operates' | 'Status' | 'Tags' | 'DetailInfo' | 'Price' | 'CopyCol' | 'IndexCol' | 'LongText2Ellipsis';
    /** 组件入参 */
    componentProps?: object;
    /**数据映射 */
    formatValues?: (any: any) => any;
};
export interface ButtonItem extends Omit<YwButtonProps, 'type' | 'children'> {
    type: 'batch' | 'left' | 'action';
}
export declare type GetTableData<T extends object> = (params: T & {
    pageIndex?: number;
    pageSize?: number;
}) => Promise<{
    totalNumber: number;
    pageIndex: number;
    pageSize: number;
    list: object[];
}>;
export interface rowSelection extends TableRowSelection<any> {
    hideSelectTotal?: boolean;
}
export interface YwTableProps<SearchProps extends object, dataSourceProps> extends Omit<TableProps<dataSourceProps>, 'rowSelection'> {
    /** 表格筛选参数 */
    filterProps?: SearchProps;
    /** 样式 */
    style?: React.CSSProperties;
    /** 顶部显示总数 */
    showTotal?: boolean;
    /** Table列信息 同 antd columns*/
    columns: Array<ColumnItem>;
    /** 操作区配置项  */
    buttons?: Array<ButtonItem>;
    /** 列表高度 虚拟列表使用  */
    rowHeight?: number;
    /** 开启虚拟列表   */
    useVirtual?: boolean;
    /** 滚动事件 虚拟列表生效   */
    onScroll?: ({ scrollTop, scrollLeft }: {
        scrollTop: number;
        scrollLeft: number;
    }) => void;
    /** 分页  */
    rowSelection?: rowSelection;
    /** 类型  */
    tableType?: 'default' | 'group';
    /** 获取数据 */
    getTableData: GetTableData<SearchProps>;
    /** 分组表单头部内容 */
    renderGroupTitle?: (any: any) => JSX.Element;
    /** 总数量渲染函数 */
    renderTotal?: (total: any) => JSX.Element;
}
export interface IItem {
    /** 标签名 */
    title?: string;
    /** 字段名 */
    name?: string;
    /** 组件名 */
    component?: 'Input' | 'TextArea' | 'Radio' | 'RadioGroup' | 'CheckboxGroup' | 'Switch' | 'NumberPicker' | 'Select' | 'TimePicker' | 'DateTimePicker' | 'WeekPicker' | 'DatePicker' | 'MonthPicker' | 'TimeRangePicker' | 'ArrayCards' | 'ArrayTable' | 'ArrayItems' | 'CascaderSelect' | 'Checkbox' | 'DatePicker' | 'DateRangePicker' | 'DateRangeGroup' | 'MonthRangePicker' | 'DateTimeRangePicker' | 'MonthRangePicker' | 'WeekRangePicker' | 'NumberRangePicker' | 'FormGrid' | 'FormGroup' | 'SearchSelect' | 'OrgSeletor' | 'EmpSeletor';
    /** 自定义组件 */
    customComponent?: any;
    /** 组件入参 */
    componentProps?: object;
    /** 校验规则 */
    rules?: any;
    /** 默认值 */
    defaultValue?: any;
    /** 表单项类型 */
    type?: SchemaTypes;
    /** 是否只读 */
    disabled?: boolean | Function;
    /** 表单项入参 */
    props?: ISchema['x-decorator-props'];
    /** 子表单项 */
    children?: any;
    /** 是否必填 */
    required?: boolean;
    /** 描述信息 */
    description?: ISchema['description'];
    /** 枚举值 */
    enum?: SchemaEnum<any>;
    /** 异步数据源请求uri */
    getDataSource?: Function;
    /** 是否只读 */
    readOnly?: boolean;
    /** 是否显示 */
    visible?: boolean;
    /** 表单装饰器 */
    decorator?: ISchema['x-decorator'];
    /** 字段阅读态 */
    preview?: ISchema['x-read-pretty'];
    /** 联动逻辑 */
    reactions?: ISchema['x-reactions'];
}
export interface ILayoutProps {
    labelAlign?: 'right' | 'left' | Array<'right' | 'left'>;
    full?: boolean;
    labelCol?: number | number[];
    wrapperCol?: number | number[];
    labelWidth?: number;
    wrapperWidth?: number;
    columns?: number;
    grid?: boolean;
    autoRow?: boolean;
    colon?: boolean;
}
export interface IButtons {
    htmlType: 'submit' | 'reset' | 'button';
    children?: React.ReactNode;
    type?: 'primary' | 'link' | 'default' | 'filter';
    size?: 'large' | 'middle' | 'small';
    name?: string;
}
export interface IButtonsProps {
    sticky: boolean;
    align: 'left' | 'center' | 'right';
}
export interface ILinkages {
    type: string;
    conditions: {
        key: string;
        value: string;
    }[] | object | undefined;
    target: string;
    targetValue: any;
}
export interface YwJsonFormProps {
    /** 样式 */
    style?: React.CSSProperties;
    /** 表单项. */
    items: IItem[];
    /** 表单默认值. */
    initialValues?: any;
    /** 操作项 */
    buttons?: IButtons[];
    /** 表单布局项 */
    layoutProps?: ILayoutProps;
    /** 表单尺寸 */
    size?: SizeType;
    /** 是否可编辑（预览态） */
    editable?: Form['editable'];
    /** 是否禁用 */
    disabled?: Form['disabled'];
    /** 操作项入参 */
    buttonsProps?: IButtonsProps;
    /** 表单联动逻辑 */
    linkages?: ILinkages[];
    /** 提交回调 */
    onSubmit?: (values: Form['values']) => void;
    /** 创建回调 */
    onCreate?: (form: Form) => void;
    /** 表单值变化 */
    onValueChange?: (values: any) => void;
    /** form 示例，不传入组件内部创建 */
    form?: Form;
}
export interface YwFilterProps {
    /** 样式 */
    style?: React.CSSProperties;
    /** 表单配置项. */
    items?: IItem[];
    /** label标签内置. */
    labelInset?: boolean;
    /** 最多展示行数. */
    maxRows?: number;
    /** 表单尺寸 */
    size?: YwJsonFormProps['size'];
    /** 最多展示列. */
    maxColumns?: number;
    /** 最少展示列. */
    minColumns?: number;
    /** 列间距. */
    columnGap?: number;
    /** 默认查询条件 */
    initialValues?: object;
    /** 条件缓存 */
    cache?: object;
    /** 表单项宽度 */
    itemWidth?: number;
    /** 是否开启 key enter 查询 */
    useKeyPress?: boolean;
    /** 是否有查询按钮 */
    hasSearchBtn?: boolean;
    /** form create */
    onCreate?: (form: Form) => void;
    /** 提交回调 */
    onSubmit?: (values: Form['values']) => void;
    /** 重置 */
    onReset?: (form: any) => void;
    /** 表单值变化 */
    onValueChange?: (values: any) => void;
}
export interface YwFormDialogProps extends ModalProps, Omit<YwJsonFormProps, 'size' | 'onOk'> {
    /** 自定义触发元素 */
    children?: React.ReactNode;
    /** 组件受控 */
    visible?: boolean;
    /** 弹窗名称 */
    title: string;
    /** 弹窗尺寸 */
    size?: 's' | 'm' | 'l' | 'full';
    /** 按钮文字 */
    btnText?: string;
    /** 按钮类型 */
    btnType?: 'primary' | 'link' | 'text' | 'ghost' | 'default' | 'dashed';
    /** 按钮禁用 */
    btnDisabled?: boolean;
    /** 表单项 同YwJsonForm */
    items: IItem[];
    /** 表单是否禁用 */
    disabled?: boolean;
    /** 表单是否可编辑 */
    editable?: boolean;
    /** 表单布局 同YwJsonForm*/
    layoutProps?: ILayoutProps;
    /** 表单 初始值*/
    initialValues?: object;
    /** 表单 初始完成*/
    onFormInit?: (form: any) => void;
    /** 取消回调*/
    onCancel?: () => void;
    /** 确认回调*/
    onConfirm?: (value: {
        [key: string]: any;
    }) => Promise<any> | void;
    /** 弹窗打开回调*/
    onOpen?: () => Promise<any>;
}
export interface YwTableDialogProps extends YwFilterProps, YwTableProps<any, any>, Pick<ModalProps, 'okText' | 'bodyStyle'> {
    /** 组件受控 */
    visible?: boolean;
    /** 弹窗名称 */
    title: any;
    /** 弹窗尺寸 */
    size?: 's' & TableProps<any>['size'];
    /** 按钮文字 */
    btnText?: string;
    /** 按钮类型 */
    btnType?: 'primary' | 'link' | 'text' | 'ghost' | 'default' | 'dashed';
    /** 按钮禁用 */
    btnDisabled?: boolean;
    /** filter表单项 同YwJsonForm */
    filterItems?: IItem[] | undefined;
    /** 表单 初始值*/
    /** 自定义触发元素 */
    children?: React.ReactNode;
    /** 关闭回调*/
    onClose?: () => void;
    /** 弹窗打开回调*/
    onOpen?: () => Promise<any>;
    /** 弹窗确定回调*/
    onOk?: (keys: any[], data: any[], info: any) => void;
    /** table初始化回调*/
    onTableInit?: (ref: React.Ref<any>) => void;
}
export interface YwContainer {
    /** style */
    style?: React.CSSProperties;
    /** className */
    className?: string;
    children?: React.ReactNode;
    linkages?: any;
}
export interface YwNoticeProps {
    /** style */
    style?: React.CSSProperties;
    /** className */
    className?: string;
    /** 文案内容 */
    content?: string | string[] | JSX.Element | JSX.Element[];
    /** 标题 */
    title?: string | JSX.Element;
    /** 类型 */
    type?: 'success' | 'warning' | 'error' | 'notice' | 'help';
    /** 是否可关闭 */
    closeable?: boolean;
    /** 自定义icon */
    icon?: React.ReactNode;
    /** 按钮文案 */
    btnText?: string;
    /** 按钮点击事件 */
    onClick?: () => void;
    /** 关闭提示事件 */
    onClose?: () => void;
}
export interface YwContainerProps {
    /** style */
    style?: React.CSSProperties;
    /** className */
    className?: string;
    /** 联动逻辑 */
    linkages?: object[];
    /** 加载状态 */
    loading?: boolean;
    /** 数据错误 */
    error?: boolean;
    /** 数据为空 */
    empty?: boolean;
    /** 标题 */
    title?: string;
}
export interface YwButtonProps extends Pick<ButtonProps, 'danger' | 'ghost' | 'type' | 'href' | 'htmlType' | 'size' | 'target' | 'onClick' | 'block' | 'loading'> {
    /** 样式 */
    style?: React.CSSProperties;
    /** className */
    className?: string;
    /** 按钮禁用 */
    disabled?: Function | boolean;
    /** 是否显示 */
    visible?: Function | boolean;
    /** 按钮文字 */
    btnText?: string;
    /** 按钮类型 */
    btnType?: ButtonProps['type'];
    /** 文案右侧icon */
    leftIcon?: React.ReactNode;
    /** 文案左侧icon */
    rightIcon?: React.ReactNode;
    /** 自定义按钮 */
    children?: React.ReactNode;
}
export interface YwDrawerSelectorProps extends Pick<YwFilterProps, 'items' | 'itemWidth' | 'initialValues'>, Pick<YwButtonProps, 'btnText' | 'btnType' | 'disabled'>, Pick<YwTableProps<any, any>, 'getTableData' | 'pagination' | 'rowSelection' | 'buttons' | 'columns' | 'rowKey'>, Pick<DrawerProps, 'width'> {
    /** 抽屉标题 */
    title?: string | ReactNode;
    /** 数据展示类型 */
    listType?: 'table' | 'card';
    /** 确认按钮文案 */
    confirmText?: string;
    /** filter表单项 同YwJsonForm */
    filterItems?: YwFilterProps['items'] | undefined;
    /** 受控模式 抽屉展示 */
    visible?: boolean;
    /** 最大可选数量 */
    maxItems?: number;
    /** 最少可选数量 */
    minItems?: number;
    /** 自定义最大可选数量错误提示 */
    renderMaxItemsMessageError?: (maxItems: number) => string;
    /** 自定义至少数量错误提示 */
    renderMinItemsMessageError?: (maxItems: number) => string;
    /** 非受控模式 触发节点 */
    children?: ReactNode;
    /** 非受控模式 提交按钮 */
    onSubmit?: (keys: React.Key[], data: any[]) => Promise<any>;
    /** 关闭回调*/
    onClose?: () => void;
    /** 图片预览字段映射*/
    formatPreviewItemValue?: <T>(data: T) => {
        imgUrl: string;
        tooltip?: TooltipProps;
    } & keyof T;
}
export interface UserInfo {
    userName: string;
    userId: string;
    headIconUrl: string;
    position: string;
    userPhone: string;
    orgPathDesc: string;
}
export interface YwEmpSelectorProps extends Omit<ModalProps, 'onOk'> {
    /**
     * 接口请求 ：通过关键词查询用户 关键词为花名、真名以及两者的拼音 接口
     */
    getDataSource: (string?: any) => Promise<UserInfo[]>;
    /**
     * 接口请求 ：通过部门id查询下级用户
     */
    getUserListForOrg: ({ orgId: number }: {
        orgId: any;
    }) => Promise<UserInfo[]>;
    /**
     * 接口请求 ：返回部门树
     */
    getOrgList: (any?: any) => Promise<UserInfo[]>;
    /**
     *  用户信息列表，数据结构同接口：通过部门id查询下级用户
     */
    dataSourceForUser?: UserInfo[];
    /**
     *  默认值
     */
    defaultValue?: UserInfo[];
    /**
     *  受控值
     */
    value?: UserInfo[];
    /**
     *  最大可选数量
     */
    maxItems?: number;
    /**
     *  字段转换
     */
    fieldNames?: {
        label: string;
        value: string;
        children: string;
    };
    /**
     *  取消回调
     */
    onCancel?: () => void;
    /**
     *  确认回调
     */
    onOk: (data: UserInfo[]) => void;
}
export interface YwOrgSelectorProps extends ModalProps {
    getDataSource: (any?: any) => Promise<any>;
    defaultValue?: {
        label: string;
        value: string;
    }[];
    fieldNames?: {
        label: string;
        value: string;
        children: string;
    };
}
export interface YwCascaderProps {
    /**
     * 数据源，结构可参考下方说明
     */
    dataSource?: Array<checkData>;
    /**
     * （非受控）默认值
     */
    defaultValue?: string | Array<string>;
    /**
     * （受控）当前值
     */
    value?: string | Array<string>;
    /**
     * 选中值改变时触发的回调函数
     */
    onChange?: (value: string | Array<string>, data: checkData | Array<checkData>, extra: any) => void;
    /**
     * （非受控）默认展开值，如果不设置，组件内部会根据 defaultValue/value 进行自动设置
     */
    defaultExpandedValue?: Array<string>;
    /**
     * （受控）当前展开值
     */
    expandedValue?: Array<string>;
    /**
     * 展开触发的方式
     */
    expandTriggerType?: 'click' | 'hover';
    /**
     * 展开时触发的回调函数
     */
    onExpand?: (expandedValue: Array<string>) => void;
    /**
     * 是否开启虚拟滚动
     */
    useVirtual?: boolean;
    /**
     * 是否多选
     */
    multiple?: boolean;
    /**
     * 单选时是否只能选中叶子节点
     */
    canOnlySelectLeaf?: boolean;
    /**
     * 多选时是否只能选中叶子节点
     */
    canOnlyCheckLeaf?: boolean;
    /**
     * 父子节点是否选中不关联
     */
    checkStrictly?: boolean;
    /**
     * 每列列表样式对象
     */
    listStyle?: React.CSSProperties;
    /**
     * 每列列表类名
     */
    listClassName?: string;
    /**
     * 每列列表项渲染函数
     */
    itemRender?: (data: checkData) => React.ReactNode;
    /**
     * 异步加载数据函数，source是原始对象
     */
    loadData?: (data: checkData, source: checkData) => void;
    /**
     * 是否是不可变数据
     */
    immutable?: boolean;
}
export interface YwCardListProps extends ListProps<any> {
    /** 分页 */
    pagination?: false | PaginationProps;
    /** 数据请求 */
    getDataSource?: (any: any) => void;
    /** 数据 */
    dataSource?: any[];
    /** 筛选项 */
    filterProps?: any;
    /** 唯一key */
    rowKey?: string;
    /** 是否展示总数 */
    showTotal?: boolean;
    /** 自定义总数 */
    renderTotal?: (number: any) => JSX.Element;
    /** 操作区 */
    buttons?: IButtons[];
    /** 确认文案 */
    confirmText?: string;
    /** 确认按钮loading */
    confirmLoading?: boolean;
    /** 确认按钮禁用 */
    confirmDisabled?: boolean;
    /** 格式化 */
    formatValues?: (any: any) => {
        [key: string]: any;
    };
    /** 是否可选择 */
    onSubmit?: (any: any) => void;
    /** 是否可选择 */
    rowSelection?: TableProps<any>['rowSelection'];
    renderHeader?: (any: any) => JSX.Element;
    renderFooter?: (any: any) => JSX.Element;
    listItemStyle?: React.CSSProperties;
    /** footer 样式 */
    footerStyle?: React.CSSProperties;
}
export interface YwTagProps extends TagProps {
    /** 业务预定义标签 */
    bizName?: string;
    /** 标签文字 */
    text?: string;
    /** 样式类型 hollow 空心样式 */
    styleType?: '' | 'hollow';
    /** 尺寸 */
    size?: 'default' | 's';
}
export {};
