"use strict";

exports.__esModule = true;
exports.camelcase = camelcase;
exports.hyphenate = hyphenate;
exports.template = template;

var _object = require("./object");

/**
 * 将字符串转化为驼峰式写法
 * @param  {String} str 例：-webkit-transition
 * @return {String}     例：WebkitTransition
 */
function camelcase(str) {
  if (!/-/.test(str)) {
    return str || '';
  }

  return str.toLowerCase().replace(/-([a-z])/g, function ($0, $1) {
    return $1.toUpperCase();
  });
}
/**
 * 将驼峰式字符串转化为连字符写法
 * @param  {String} str 例：WebkitTransition
 * @return {String}     例：-webkit-transition
 */


function hyphenate(str) {
  var strType = (0, _object.typeOf)(str);

  if (strType !== 'String') {
    return '';
  }

  return str.replace(/([A-Z])/g, function ($0) {
    return "-" + $0.toLowerCase();
  });
}
/**
 * 替换模板字符串
 * @param {String} tpl     例：当前{current}, 共{total}页
 * @param {Object} object  例：{current: 1, total: 9}
 * @return {String}        例：
 */


function template(tpl, object) {
  if (object === void 0) {
    object = {};
  }

  var tplType = (0, _object.typeOf)(tpl);

  if (tplType !== 'String') {
    return '';
  }

  return tpl.replace(/\{[a-z]*\}/g, function (str) {
    var key = str.substring(1, str.length - 1);
    return object[key] || '';
  });
}